Index: recipes/skia_buildbot.py |
diff --git a/recipes/skia.py b/recipes/skia_buildbot.py |
similarity index 72% |
copy from recipes/skia.py |
copy to recipes/skia_buildbot.py |
index 171157c43ffaac2108a107db07e59981737d839e..42b6c8dad956c811ff87d5a7e7670223e70727d1 100644 |
--- a/recipes/skia.py |
+++ b/recipes/skia_buildbot.py |
@@ -9,14 +9,14 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Skia(recipe_util.Recipe): |
- """Basic Recipe class for the Skia repository.""" |
+class SkiaBuildbot(recipe_util.Recipe): |
+ """Basic Recipe class for the Skia Buildbot repository.""" |
@staticmethod |
def fetch_spec(_props): |
solution = { |
- 'name' : 'skia', |
- 'url' : 'https://skia.googlesource.com/skia.git', |
+ 'name' : 'buildbot', |
+ 'url' : 'https://skia.googlesource.com/buildbot.git', |
'deps_file': 'DEPS', |
'managed' : False, |
} |
@@ -30,11 +30,11 @@ class Skia(recipe_util.Recipe): |
@staticmethod |
def expected_root(_props): |
- return 'skia' |
+ return 'buildbot' |
def main(argv=None): |
- return Skia().handle_args(argv) |
+ return SkiaBuildbot().handle_args(argv) |
if __name__ == '__main__': |